@@ -22,11 +22,13 @@ import csv
 import logging
 import subprocess
 import urllib
+from StringIO import StringIO
 from zc.buildout import download
 import urlparse
 
 log = logging.getLogger('lovely.buildouthttp')
 
+
 def get_github_credentials():
 
     """returns the credentials for the local git installation by using
@@ -72,6 +74,7 @@ class GithubHandler(urllib2.BaseHandler):
             req.timeout = timeout
         return req
 
+
 class CredHandler(urllib2.HTTPBasicAuthHandler):
 
     """This handler adds basic auth credentials to the request upon a 401
@@ -97,8 +100,8 @@ class CredHandler(urllib2.HTTPBasicAuthHandler):
 
         log.debug('getting url: %r' % req.get_full_url())
         try:
-            res =  urllib2.HTTPBasicAuthHandler.http_error_401(
-                self,req, fp, code, msg, headers)
+            res = urllib2.HTTPBasicAuthHandler.http_error_401(
+                self, req, fp, code, msg, headers)
         except urllib2.HTTPError, err:
             log.error('failed to get url: %r %r', req.get_full_url(), err.code)
             raise
@@ -109,23 +112,43 @@ class CredHandler(urllib2.HTTPBasicAuthHandler):
             if res is None:
                 log.error('failed to get url: %r, check your realm',
                           req.get_full_url())
-            elif res.code>=400:
+            elif res.code >= 400:
                 log.error('failed to get url: %r %r', res.url, res.code)
             else:
                 log.debug('got url: %r %r', res.url, res.code)
             return res
 
+
 def install(buildout=None, pwd_path=None):
-    pwdsf = None
+    pwdsf = StringIO()
+    combined_creds = []
     github_creds = None
     creds = []
-    try:
-        pwd_path = pwd_path or os.path.join(os.path.expanduser('~'),
-                                  '.buildout',
-                                  '.httpauth')
-        pwdsf = file(pwd_path)
-    except IOError, e:
-        log.warn('Could not load authentication information: %s' % e)
+    local_pwd_path = ''
+    if buildout is not None:
+        local_pwd_path = os.path.join(
+            buildout['buildout']['directory'],
+            '.httpauth')
+    system_pwd_path = os.path.join(
+        os.path.expanduser('~'),
+        '.buildout',
+        '.httpauth')
+
+    def combine_cred_file(file_path, combined_creds):
+        if file_path is None or not os.path.exists(file_path):
+            return
+        cred_file = file(file_path)
+        combined_creds += map(str.strip, cred_file.readlines())
+        cred_file.close()
+    # combine all the possible .httpauth files together
+    combine_cred_file(pwd_path, combined_creds)
+    combine_cred_file(local_pwd_path, combined_creds)
+    combine_cred_file(system_pwd_path, combined_creds)
+    pwdsf.write("\n".join(combined_creds))
+    pwdsf.seek(0)
+    if not pwdsf.len:
+        pwdsf = None
+        log.warn('Could not load authentication information')
     try:
         auth_handler = CredHandler()
         github_creds = get_github_credentials()
@@ -137,7 +160,7 @@ def install(buildout=None, pwd_path=None):
                 if len(row) != 4:
                     raise RuntimeError(
                         "Authentication file cannot be parsed %s:%s" % (
-                            pwd_path, l+1))
+                            pwd_path, l + 1))
                 realm, uris, user, password = (el.strip() for el in row)
                 creds.append((realm, uris, user, password))
                 log.debug('Added credentials %r, %r' % (realm, uris))
@@ -158,6 +181,7 @@ def install(buildout=None, pwd_path=None):
         if pwdsf:
             pwdsf.close()
 
+
 class URLOpener(download.URLOpener):
 
     def __init__(self, creds, github_creds):
@@ -170,7 +194,8 @@ class URLOpener(download.URLOpener):
 
     def retrieve(self, url, filename=None, reporthook=None, data=None):
         if self.github_creds and not data:
-            scheme, netloc, path, params, query, fragment =  urlparse.urlparse(url)
+            scheme, netloc, path, params, query, fragment = urlparse.urlparse(
+                url)
             if scheme == 'https' and netloc == 'github.com':
                 log.debug("Appending github credentials to url %r", url)
                 login, token = self.github_creds
